%feature("docstring") OT::KrigingResult
"Kriging result.

Notes
-----
Structure created by the method run() of a :class:`~openturns.KrigingAlgorithm`,
and obtained thanks to the method getResult().

Examples
--------
>>> import openturns as ot
>>> f = ot.NumericalMathFunction(['x0'], ['y'], ['x0 * sin(x0)'])
>>> sampleX = [[1.0], [2.0], [3.0], [4.0], [5.0], [6.0]]
>>> sampleY = f(sampleX)
>>> basis = ot.Basis([ot.NumericalMathFunction('x', 'x'), ot.NumericalMathFunction('x', 'x^2')])
>>> covarianceModel = ot.GeneralizedExponential(1, 2.0, 2.0)
>>> algoKriging = ot.KrigingAlgorithm(sampleX, sampleY, basis, covarianceModel)
>>> algoKriging.run()
>>> resKriging = algoKriging.getResult()
>>> metaModel = resKriging.getMetaModel()
>>> graph = metaModel.draw(0.0, 7.0)
>>> cloud = ot.Cloud(sampleX, sampleY)
>>> cloud.setPointStyle('fcircle')
>>> graph.add(cloud)
>>> graph.add(f.draw(0.0, 7.0))
>>> graph.setColors(['black', 'blue', 'red'])
"

// ---------------------------------------------------------------------

%feature("docstring") OT::KrigingResult::getCovarianceCoefficients
"Accessor to the covariance coefficients.

Returns
-------
covCoeff :   :class:`~openturns.NumericalSample` which size is the ouput dimension of :math:`f` and which dimension is :math:`p`.

Notes
-----
Each point of the sample refers to the vector:

.. math::
    \\\\Tr{\\\\vect{c}_{\\\\vect{\\\\theta}}(\\\\vect{x})}\\\\mat{C}^{-1}(\\\\vect{y}-\\\\mat{F}\\\\, \\\\tilde{\\\\vect{\\\\beta}})
"

// ---------------------------------------------------------------------

%feature("docstring") OT::KrigingResult::getTrendCoefficients
"Accessor to the coefficients of the generalized linear model of the trend.

Parameters
----------
trendCoef :  :class:`~openturns.NumericalSample` which size is the ouput dimension of :math:`f` and which dimension is :math:`p`.

Notes
-----
Each point of the sample refers to the vector:

.. math::
    \\\\left(\\\\beta_1, \\\\ldots, \\\\beta_p\\\\right)
"

// ---------------------------------------------------------------------

%feature("docstring") OT::KrigingResult::getCovarianceModels
"Accessor to the collection of covariance models.

Returns
-------
covModelColl : list of :class:`~openturns.CovarianceModel` which size is the ouput dimension of :math:`f`.

Notes
-----
Each covariance model refers to the function :math:`c_{\\\\vect{\\\\theta}}(\\\\vect{x}, \\\\vect{y})`.
" 
    

// ---------------------------------------------------------------------

%feature("docstring") OT::KrigingResult::getBasis
"Accessor to the basis of the generalized linear model.

Returns
-------
basis : :class:`~openturns.Basis`
    Basis of the generalized linear model.
"
