%feature("docstring") OT::LogNormal
"Lognormal distribution.

Available constructors:
    LogNormal(*arg1=0., arg2=1.0, gamma=0., parameters_set=ot.LogNormal.MUSIGMA_LOG*)

Parameters
----------
arg1 : float
    If `parameters_set == ot.LogNormal.MUSIGMA_LOG`: location parameter
    :math:`\\\\mu_\\\\ell`.

    If `parameters_set == ot.LogNormal.MUSIGMA`: mean.

    If `parameters_set == ot.LogNormal.MU_SIGMAOVERMU`: mean.
arg2 : float, :math:`arg2 > 0`
    If `parameters_set == ot.LogNormal.MUSIGMA_LOG`: scale parameter
    :math:`\\\\sigma_\\\\ell`.

    If `parameters_set == ot.LogNormal.MUSIGMA`: standard deviation.

    If `parameters_set == ot.LogNormal.MU_SIGMAOVERMU`: coefficient of
    variation :math:`\\\\delta = \\\\sigma/\\\\mu, \\\\mu \\\\neq 0`.
gamma : float, optional
    Shift parameter :math:`\\\\gamma < \\\\mu`.
parameters_set : int, optional
    Integer telling which parameters set is used for defining the
    distribution (amongst `ot.LogNormal.MUSIGMA_LOG, ot.LogNormal.MUSIGMA,
    ot.LogNormal.MU_SIGMAOVERMU`).

Notes
-----
Its probability density function is defined as:

.. math::

    f_X(x) = \\\\frac{1}{\\\\sqrt{2\\\\pi}\\\\sigma_\\\\ell (x - \\\\gamma)}
             \\\\exp\\\\left(- \\\\frac{1}{2}
                       \\\\left(\\\\frac{\\\\log(x - \\\\gamma) - \\\\mu_\\\\ell}
                                  {\\\\sigma_\\\\ell}\\\\right)^2\\\\right),
             \\\\quad x \\\\in [\\\\gamma; +\\\\infty[

with :math:`\\\\gamma, \\\\mu_\\\\ell \\\\in \\\\Rset` and :math:`\\\\sigma_\\\\ell > 0`.

Its first moments are:

.. math::
    :nowrap:

    \\\\begin{eqnarray*}
        \\\\Expect{X} & = & \\\\exp\\\\left(\\\\mu_\\\\ell + \\\\sigma_\\\\ell^2 / 2\\\\right) + \\\\gamma \\\\\\\\
        \\\\Var{X} & = & \\\\exp\\\\left(2 \\\\mu_\\\\ell + \\\\sigma_\\\\ell^2\\\\right)
                      \\\\left(\\\\exp(\\\\sigma_\\\\ell^2) - 1\\\\right)
    \\\\end{eqnarray*}

Examples
--------
Create a distribution:

>>> import openturns as ot
>>> distribution = ot.LogNormal(0., 1., 0.)

Draw a sample:

>>> sample = distribution.getSample(10)"

// ---------------------------------------------------------------------

%feature("docstring") OT::LogNormal::getGamma
"Accessor to the distribution's shift parameter :math:`\\\\gamma`.

Returns
-------
gamma : float
    Shift parameter :math:`\\\\gamma`."

// ---------------------------------------------------------------------

%feature("docstring") OT::LogNormal::getMu
"Accessor to the distribution's mean.

Returns
-------
mu : float
    Mean."

// ---------------------------------------------------------------------

%feature("docstring") OT::LogNormal::getMuLog
"Accessor to the distribution's location parameter :math:`\\\\mu_\\\\ell`.

Returns
-------
mu_log : float
    Location parameter :math:`\\\\mu_\\\\ell`."

// ---------------------------------------------------------------------

%feature("docstring") OT::LogNormal::getSigma
"Accessor to the distribution's standard deviation.

Returns
-------
sigma : float
    Standard deviation."

// ---------------------------------------------------------------------

%feature("docstring") OT::LogNormal::getSigmaLog
"Accessor to the distribution's scale parameter :math:`\\\\sigma_\\\\ell`.

Returns
-------
sigma_log : float
    Scale parameter :math:`\\\\sigma_\\\\ell`."

// ---------------------------------------------------------------------

%feature("docstring") OT::LogNormal::getSigmaOverMu
"Accessor to the distribution's coefficient of variation (if defined).

Returns
-------
cov : float
    Coefficient of variation :math:`\\\\sigma/\\\\mu, \\\\mu \\\\neq 0`."

// ---------------------------------------------------------------------

%feature("docstring") OT::LogNormal::setGamma
"Accessor to the distribution's shift parameter :math:`\\\\gamma`.

Parameters
----------
gamma : float, :math:`\\\\gamma < \\\\mu`
    Shift parameter :math:`\\\\gamma`."

// ---------------------------------------------------------------------

%feature("docstring") OT::LogNormal::setMuLog
"Accessor to the distribution's location parameter :math:`\\\\mu_\\\\ell`.

Parameters
----------
mu_log : float, :math:`\\\\mu_\\\\ell \\\\in \\\\Rset`
    Location parameter :math:`\\\\mu_\\\\ell`."

// ---------------------------------------------------------------------

%feature("docstring") OT::LogNormal::setSigmaLog
"Accessor to the distribution's scale parameter :math:`\\\\sigma_\\\\ell`.

Parameters
----------
sigma_log : float, :math:`\\\\sigma_\\\\ell > 0`
    Scale parameter :math:`\\\\sigma_\\\\ell`."

// ---------------------------------------------------------------------

%feature("docstring") OT::LogNormal::setMuSigma
"Accessor to the distribution's mean and standard deviation.

Parameters
----------
mu : float, :math:`\\\\mu > \\\\gamma`
    Mean.
sigma : float, :math:`\\\\sigma > 0`
    Standard deviation."