#                                               -*- cmake -*-
#
#  OpenTURNSConfig.cmake(.in)
#
#  Find OpenTURNS includes and libraries
#
#  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
#
#  This library is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  along with this library.  If not, see <http://www.gnu.org/licenses/>.
#
#  @author schueller
#  @date   2010-02-04 16:44:49 +0100 (Thu, 04 Feb 2010)
#

# Use the following variables to compile and link against OpenTURNS:
#  OPENTURNS_FOUND              - True if OpenTURNS was found on your system
#  OPENTURNS_USE_FILE           - The file making OpenTURNS usable
#  OPENTURNS_DEFINITIONS        - Definitions needed to build with OpenTURNS
#  OPENTURNS_INCLUDE_DIR        - Directory where OT.hxx can be found
#  OPENTURNS_INCLUDE_DIRS       - List of directories of OpenTURNS and it's dependencies
#  OPENTURNS_LIBRARY            - OpenTURNS library location
#  OPENTURNS_LIBRARIES          - List of libraries to link against
#  OPENTURNS_WRAPPER_LIBRARIES  - List of wrapper libraries to link against
#  OPENTURNS_LIBRARY_DIRS       - List of directories containing OpenTURNS' libraries
#  OPENTURNS_ROOT_DIR           - The base directory of OpenTURNS
#  OPENTURNS_VERSION_STRING     - A human-readable string containing the version
#  OPENTURNS_VERSION_MAJOR      - The major version of OpenTURNS
#  OPENTURNS_VERSION_MINOR      - The minor version of OpenTURNS
#  OPENTURNS_VERSION_PATCH      - The patch version of OpenTURNS
#  OPENTURNS_SWIG_INCLUDE_DIRS  - Location of swig interface files
#  OPENTURNS_SWIG_DEFINITIONS   - Definitions to compile the swig generated source
#  OPENTURNS_PYTHON_MODULE_PATH - Path to the python module


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was OpenTURNSConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/openturns" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

####################################################################################

set ( OPENTURNS_FOUND 1 )
set_and_check ( OPENTURNS_USE_FILE   "${PACKAGE_PREFIX_DIR}/lib/cmake/openturns/UseOpenTURNS.cmake" )

set ( OPENTURNS_DEFINITIONS  "" )
set_and_check ( OPENTURNS_INCLUDE_DIR        "${PACKAGE_PREFIX_DIR}/include/openturns" )
set ( OPENTURNS_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include/openturns;${PACKAGE_PREFIX_DIR}/include;${PACKAGE_PREFIX_DIR}/lib/cmake/hmat/../../../include/hmat;${PACKAGE_PREFIX_DIR}/include/libxml2" )
set ( OPENTURNS_LIBRARY      "OT" )
set ( OPENTURNS_LIBRARIES    "/usr/lib/liblapack.so;/usr/lib/libblas.so;/usr/lib/mips64el-linux-gnu/libmuparser.so;hmat-oss;/usr/lib/mips64el-linux-gnu/libxml2.so;-lpthread;/usr/lib/mips64el-linux-gnu/libdl.so;/usr/lib/mips64el-linux-gnu/libc.so;OT" )
set ( OPENTURNS_WRAPPER_LIBRARIES    "/usr/lib/liblapack.so;/usr/lib/libblas.so;/usr/lib/mips64el-linux-gnu/libmuparser.so;hmat-oss;/usr/lib/mips64el-linux-gnu/libxml2.so;-lpthread;/usr/lib/mips64el-linux-gnu/libdl.so;/usr/lib/mips64el-linux-gnu/libc.so;OT;OTbind" )
set ( OPENTURNS_LIBRARY_DIRS "${PACKAGE_PREFIX_DIR}/lib" )
set_and_check ( OPENTURNS_ROOT_DIR   "${PACKAGE_PREFIX_DIR}/" )

set ( OPENTURNS_VERSION_STRING "1.5" )
set ( OPENTURNS_VERSION_MAJOR  "1" )
set ( OPENTURNS_VERSION_MINOR  "5" )
set ( OPENTURNS_VERSION_PATCH  "" )

set_and_check ( OPENTURNS_SWIG_INCLUDE_DIRS  "${PACKAGE_PREFIX_DIR}/include/openturns/swig" )
set ( OPENTURNS_SWIG_DEFINITIONS   "-DSWIG_TYPE_TABLE=openturns" )
set ( OPENTURNS_PYTHON_MODULE_PATH "/usr/lib/python3/dist-packages" )

